@@ -137,16 +137,16 @@ def debable(labellings,pivot,subsample_size='none'):
         translated_list.append(not_lar_translated)
     return translated_list
 
-def accuracy(labels1,labels2,subsample_size='none'):
+def accuracy(labels1,labels2,subsample_size='none',precision=4):
     if labels1.shape != labels2.shape:
         raise TranslationError(f"labels1: {labels1.shape} doesn't equal labels2 shape: {labels2.shape}")
     if len(labels1) == 0:
         warnings.warn("You're translating an empty labelling")
         return 0
     trans_labels = translate_labellings(labels1,labels2,subsample_size)
-    return sum(trans_labels==numpyify(labels2))/len(labels1)
+    return round(sum(trans_labels==numpyify(labels2))/len(labels1),precision)
 
-def f1(bin_classifs_pred,bin_classifs_gt):
+def f1(bin_classifs_pred,bin_classifs_gt,precision=4):
     tp = sum(bin_classifs_pred*bin_classifs_gt)
     if tp==0: return 0
     fp = sum(bin_classifs_pred*~bin_classifs_gt)
@@ -154,16 +154,16 @@ def f1(bin_classifs_pred,bin_classifs_gt):
 
     prec = tp/(tp+fp)
     rec = tp/(tp+fn)
-    return (2*prec*rec)/(prec+rec)
+    return round((2*prec*rec)/(prec+rec),precision)
 
-def mean_f1(labels1,labels2,subsample_size='none'):
+def mean_f1(labels1,labels2,subsample_size='none',precision=4):
     trans_labels = translate_labellings(labels1,labels2,subsample_size)
     lab_f1s = []
     for lab in unique_labels(trans_labels):
         lab_booleans1 = trans_labels==lab
         lab_booleans2 = labels2==lab
-        lab_f1s.append(f1(lab_booleans1,lab_booleans2))
-    return sum(lab_f1s)/len(lab_f1s)
+        lab_f1s.append(f1(lab_booleans1,lab_booleans2,precision=15))
+    return round(sum(lab_f1s)/len(lab_f1s),precision)
 
 def compress_labels(labels):
     if isinstance(labels,torch.Tensor): labels = labels.detach().cpu().numpy()
